# Generated by Django 2.2.11 on 2021-06-25 09:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('apis_highlighter', '0004_auto_20210623_2124'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='annotation',
            name='entity_link',
        ),
    ]
